@@ -12,6 +12,14 @@ def check(check_ctxt, msgs, key, msgsrc, settings):
     pass
 
 
+def dump_addon_bl_info(msgs, reports, module, settings):
+    ''' 
+
+    '''
+
+    pass
+
+
 def dump_addon_messages(module_name, do_checks, settings):
     ''' 
 
@@ -68,6 +76,14 @@ def dump_src_messages(msgs, reports, settings):
     pass
 
 
+def dump_template_messages(msgs, reports, settings):
+    ''' 
+
+    '''
+
+    pass
+
+
 def init_spell_check(settings, lang):
     ''' 
 
