@@ -1082,11 +1082,38 @@ class _defs_annotate:
 
 
 class _defs_curves_sculpt:
-    def generate_from_brushes(self, context):
-        ''' 
+    add = None
+    ''' '''
 
-        '''
-        pass
+    comb = None
+    ''' '''
+
+    delete = None
+    ''' '''
+
+    density = None
+    ''' '''
+
+    grow_shrink = None
+    ''' '''
+
+    pinch = None
+    ''' '''
+
+    puff = None
+    ''' '''
+
+    selection_paint = None
+    ''' '''
+
+    slide = None
+    ''' '''
+
+    smooth = None
+    ''' '''
+
+    snake_hook = None
+    ''' '''
 
 
 class _defs_edit_armature:
@@ -1525,6 +1552,12 @@ class _defs_transform:
     translate = None
     ''' '''
 
+    def draw_transform_sculpt_tool_settings(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
 
 class _defs_vertex_paint:
     def generate_from_brushes(self, context):
