@@ -278,6 +278,21 @@ class BMEdgeSeq:
         '''
         pass
 
+    def __iter__(self):
+        ''' 
+
+        '''
+        pass
+
+    def __getitem__(self, key: int) -> 'BMEdge':
+        ''' 
+
+        :param key: 
+        :type key: int
+        :rtype: 'BMEdge'
+        '''
+        pass
+
 
 class BMEditSelIter:
     pass
@@ -331,6 +346,12 @@ class BMElemSeq:
         '''
         pass
 
+    def __iter__(self):
+        ''' 
+
+        '''
+        pass
+
 
 class BMFace:
     ''' The BMesh face with 3 or more sides
@@ -596,6 +617,21 @@ class BMFaceSeq:
         '''
         pass
 
+    def __iter__(self):
+        ''' 
+
+        '''
+        pass
+
+    def __getitem__(self, key: int) -> 'BMFace':
+        ''' 
+
+        :param key: 
+        :type key: int
+        :rtype: 'BMFace'
+        '''
+        pass
+
 
 class BMIter:
     ''' Internal BMesh type for looping over verts/faces/edges, used for iterating over `BMElemSeq` types.
@@ -974,6 +1010,21 @@ class BMLoopSeq:
     :type: 'BMLayerAccessLoop'
     '''
 
+    def __iter__(self):
+        ''' 
+
+        '''
+        pass
+
+    def __getitem__(self, key: int) -> 'BMLoop':
+        ''' 
+
+        :param key: 
+        :type key: int
+        :rtype: 'BMLoop'
+        '''
+        pass
+
 
 class BMLoopUV:
     pin_uv: bool = None
@@ -1196,6 +1247,21 @@ class BMVertSeq:
         '''
         pass
 
+    def __iter__(self):
+        ''' 
+
+        '''
+        pass
+
+    def __getitem__(self, key: int) -> 'BMVert':
+        ''' 
+
+        :param key: 
+        :type key: int
+        :rtype: 'BMVert'
+        '''
+        pass
+
 
 class BMesh:
     ''' The BMesh data structure
