@@ -7,14 +7,14 @@ GenericType = typing.TypeVar("GenericType")
 
 def abspath(path,
             *,
-            start: typing.Union[str, bytes] = None,
-            library: 'bpy.types.Library' = None) -> str:
+            start: typing.Optional[typing.Union[str, bytes]] = None,
+            library: typing.Optional['bpy.types.Library'] = None) -> str:
     ''' Returns the absolute path relative to the current blend file using the "//" prefix.
 
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[str, bytes]
+    :type start: typing.Optional[typing.Union[str, bytes]]
     :param library: The library this path is from. This is only included for convenience, when the library is not None its path replaces *start*.
-    :type library: 'bpy.types.Library'
+    :type library: typing.Optional['bpy.types.Library']
     :rtype: str
     :return: The absolute path.
     '''
@@ -23,7 +23,7 @@ def abspath(path,
 
 
 def basename(path) -> str:
-    ''' Equivalent to os.path.basename , but skips a "//" prefix. Use for Windows compatibility.
+    ''' Equivalent to ``os.path.basename``, but skips a "//" prefix. Use for Windows compatibility.
 
     :rtype: str
     :return: The base name of the given path.
@@ -32,13 +32,15 @@ def basename(path) -> str:
     pass
 
 
-def clean_name(name: typing.Union[str, bytes], *, replace: str = '_') -> str:
+def clean_name(name: typing.Optional[typing.Union[str, bytes]],
+               *,
+               replace: typing.Optional[str] = '_') -> str:
     ''' Returns a name with characters replaced that may cause problems under various circumstances, such as writing to a file. All characters besides A-Z/a-z, 0-9 are replaced with "_" or the *replace* argument if defined.
 
     :param name: The path name.
-    :type name: typing.Union[str, bytes]
+    :type name: typing.Optional[typing.Union[str, bytes]]
     :param replace: The replacement for non-valid characters.
-    :type replace: str
+    :type replace: typing.Optional[str]
     :rtype: str
     :return: The cleaned name.
     '''
@@ -46,16 +48,18 @@ def clean_name(name: typing.Union[str, bytes], *, replace: str = '_') -> str:
     pass
 
 
-def display_name(name: str, *, has_ext: bool = True,
-                 title_case: bool = True) -> str:
+def display_name(name: typing.Optional[str],
+                 *,
+                 has_ext: typing.Optional[bool] = True,
+                 title_case: typing.Optional[bool] = True) -> str:
     ''' Creates a display string from name to be used menus and the user interface. Intended for use with filenames and module names.
 
     :param name: The name to be used for displaying the user interface.
-    :type name: str
+    :type name: typing.Optional[str]
     :param has_ext: Remove file extension from name.
-    :type has_ext: bool
+    :type has_ext: typing.Optional[bool]
     :param title_case: Convert lowercase names to title case.
-    :type title_case: bool
+    :type title_case: typing.Optional[bool]
     :rtype: str
     :return: The display string.
     '''
@@ -63,11 +67,11 @@ def display_name(name: str, *, has_ext: bool = True,
     pass
 
 
-def display_name_from_filepath(name: str) -> str:
+def display_name_from_filepath(name: typing.Optional[str]) -> str:
     ''' Returns the path stripped of directory and extension, ensured to be utf8 compatible.
 
     :param name: The file path to convert.
-    :type name: str
+    :type name: typing.Optional[str]
     :rtype: str
     :return: The display name.
     '''
@@ -75,11 +79,11 @@ def display_name_from_filepath(name: str) -> str:
     pass
 
 
-def display_name_to_filepath(name: str) -> str:
+def display_name_to_filepath(name: typing.Optional[str]) -> str:
     ''' Performs the reverse of display_name using literal versions of characters which aren't supported in a filepath.
 
     :param name: The display name to convert.
-    :type name: str
+    :type name: typing.Optional[str]
     :rtype: str
     :return: The file path.
     '''
@@ -87,16 +91,18 @@ def display_name_to_filepath(name: str) -> str:
     pass
 
 
-def ensure_ext(filepath: str, ext: str, *,
-               case_sensitive: bool = False) -> str:
+def ensure_ext(filepath: typing.Optional[str],
+               ext: typing.Optional[str],
+               *,
+               case_sensitive: typing.Optional[bool] = False) -> str:
     ''' Return the path with the extension added if it is not already set.
 
     :param filepath: The file path.
-    :type filepath: str
+    :type filepath: typing.Optional[str]
     :param ext: The extension to check for, can be a compound extension. Should start with a dot, such as '.blend' or '.tar.gz'.
-    :type ext: str
+    :type ext: typing.Optional[str]
     :param case_sensitive: Check for matching case when comparing extensions.
-    :type case_sensitive: bool
+    :type case_sensitive: typing.Optional[bool]
     :rtype: str
     :return: The file path with the given extension.
     '''
@@ -104,11 +110,12 @@ def ensure_ext(filepath: str, ext: str, *,
     pass
 
 
-def is_subdir(path: typing.Union[str, bytes], directory) -> bool:
+def is_subdir(path: typing.Optional[typing.Union[str, bytes]],
+              directory) -> bool:
     ''' Returns true if *path* in a subdirectory of *directory*. Both paths must be absolute.
 
     :param path: An absolute path.
-    :type path: typing.Union[str, bytes]
+    :type path: typing.Optional[typing.Union[str, bytes]]
     :rtype: bool
     :return: Whether or not the path is a subdirectory.
     '''
@@ -116,13 +123,15 @@ def is_subdir(path: typing.Union[str, bytes], directory) -> bool:
     pass
 
 
-def module_names(path: str, *, recursive: bool = False) -> typing.List[str]:
+def module_names(path: typing.Optional[str],
+                 *,
+                 recursive: typing.Optional[bool] = False) -> typing.List[str]:
     ''' Return a list of modules which can be imported from *path*.
 
     :param path: a directory to scan.
-    :type path: str
+    :type path: typing.Optional[str]
     :param recursive: Also return submodule names for packages.
-    :type recursive: bool
+    :type recursive: typing.Optional[bool]
     :rtype: typing.List[str]
     :return: a list of string pairs (module_name, module_file).
     '''
@@ -130,11 +139,11 @@ def module_names(path: str, *, recursive: bool = False) -> typing.List[str]:
     pass
 
 
-def native_pathsep(path: str) -> str:
-    ''' Replace the path separator with the systems native os.sep .
+def native_pathsep(path: typing.Optional[str]) -> str:
+    ''' Replace the path separator with the systems native ``os.sep``.
 
     :param path: The path to replace.
-    :type path: str
+    :type path: typing.Optional[str]
     :rtype: str
     :return: The path with system native separators.
     '''
@@ -142,11 +151,11 @@ def native_pathsep(path: str) -> str:
     pass
 
 
-def reduce_dirs(dirs: typing.List[str]) -> typing.List[str]:
+def reduce_dirs(dirs: typing.Optional[typing.List[str]]) -> typing.List[str]:
     ''' Given a sequence of directories, remove duplicates and any directories nested in one of the other paths. (Useful for recursive path searching).
 
     :param dirs: Sequence of directory paths.
-    :type dirs: typing.List[str]
+    :type dirs: typing.Optional[typing.List[str]]
     :rtype: typing.List[str]
     :return: A unique list of paths.
     '''
@@ -154,15 +163,15 @@ def reduce_dirs(dirs: typing.List[str]) -> typing.List[str]:
     pass
 
 
-def relpath(path: typing.Union[str, bytes],
+def relpath(path: typing.Optional[typing.Union[str, bytes]],
             *,
-            start: typing.Union[str, bytes] = None) -> str:
+            start: typing.Optional[typing.Union[str, bytes]] = None) -> str:
     ''' Returns the path relative to the current blend file using the "//" prefix.
 
     :param path: An absolute path.
-    :type path: typing.Union[str, bytes]
+    :type path: typing.Optional[typing.Union[str, bytes]]
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[str, bytes]
+    :type start: typing.Optional[typing.Union[str, bytes]]
     :rtype: str
     :return: The relative path.
     '''
@@ -170,11 +179,11 @@ def relpath(path: typing.Union[str, bytes],
     pass
 
 
-def resolve_ncase(path: str) -> str:
+def resolve_ncase(path: typing.Optional[str]) -> str:
     ''' Resolve a case insensitive path on a case sensitive system, returning a string with the path if found else return the original path.
 
     :param path: The path name to resolve.
-    :type path: str
+    :type path: typing.Optional[str]
     :rtype: str
     :return: The resolved path.
     '''
