@@ -2,8 +2,8 @@ import sys
 import typing
 import bpy.types
 
-from . import units
 from . import previews
+from . import units
 
 GenericType = typing.TypeVar("GenericType")
 
@@ -320,14 +320,14 @@ def smpte_from_frame(frame: typing.Optional[int], *, fps=None,
     pass
 
 
-def smpte_from_seconds(time: typing.Union[int, float],
+def smpte_from_seconds(time: typing.Optional[typing.Union[int, float]],
                        *,
                        fps=None,
                        fps_base=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: ``HH:MM:SS:FF``. If *fps* and *fps_base* are not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[int, float]
+    :type time: typing.Optional[typing.Union[int, float]]
     :rtype: str
     :return: the frame string.
     '''
