@@ -61,12 +61,12 @@ def bake_action_iter(obj: 'bpy.types.Object',
 
 
 def bake_action_objects(object_action_pairs, *, frames: int,
-                        **kwargs) -> typing.Sequence['bpy.types.Action']:
+                        **kwargs) -> typing.Iterable['bpy.types.Action']:
     ''' A version of :func:`bake_action_objects_iter` that takes frames and returns the output.
 
     :param frames: Frames to bake.
     :type frames: int
-    :rtype: typing.Sequence['bpy.types.Action']
+    :rtype: typing.Iterable['bpy.types.Action']
     :return: A sequence of Action or None types (aligned with `object_action_pairs`)
     '''
 
