@@ -46,25 +46,25 @@ def mesh_linked_triangles(mesh: 'bpy.types.Mesh') -> typing.List:
 
 
 def mesh_linked_uv_islands(mesh: 'bpy.types.Mesh') -> typing.List:
-    ''' Splits the mesh into connected polygons, use this for separating cubes from other mesh elements within 1 mesh datablock.
+    ''' Returns lists of polygon indices connected by UV islands.
 
     :param mesh: the mesh used to group with.
     :type mesh: 'bpy.types.Mesh'
     :rtype: typing.List
-    :return: lists of lists containing polygon indices
+    :return: list of lists containing polygon indices
     '''
 
     pass
 
 
-def ngon_tessellate(from_data: typing.List['bpy.types.Mesh'],
+def ngon_tessellate(from_data: typing.Union[typing.List, 'bpy.types.Mesh'],
                     indices: typing.List,
                     fix_loops: bool = True,
                     debug_print=True):
     ''' Takes a polyline of indices (ngon) and returns a list of face index lists. Designed to be used for importers that need indices for an ngon to create from existing verts.
 
     :param from_data: either a mesh, or a list/tuple of vectors.
-    :type from_data: typing.List['bpy.types.Mesh']
+    :type from_data: typing.Union[typing.List, 'bpy.types.Mesh']
     :param indices: a list of indices to use this list is the ordered closed polyline to fill, and can be a subset of the data given.
     :type indices: typing.List
     :param fix_loops: If this is enabled polylines that use loops to make multiple polylines are delt with correctly.
@@ -75,13 +75,15 @@ def ngon_tessellate(from_data: typing.List['bpy.types.Mesh'],
 
 
 def triangle_random_points(
-        num_points,
-        loop_triangles: 'bpy.types.MeshLoopTriangle') -> typing.List:
+        num_points: typing.Any, loop_triangles: typing.
+        Union['bpy.types.MeshLoopTriangle', typing.Sequence]) -> typing.List:
     ''' Generates a list of random points over mesh loop triangles.
 
+    :type int: typing.Any
     :param loop_triangles: list of the triangles to generate points on.
-    :type loop_triangles: 'bpy.types.MeshLoopTriangle'
+    :type loop_triangles: typing.Union['bpy.types.MeshLoopTriangle', typing.Sequence]
     :param num_points:  the number of random points to generate on each triangle.
+    :type num_points: typing.Any
     :rtype: typing.List
     :return: list of random points over all triangles.
     '''
