@@ -14,7 +14,7 @@ class AndUP1D:
 
 
 class ContourUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > ContourUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ContourUP1D`
     '''
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
@@ -29,7 +29,7 @@ class ContourUP1D:
 
 
 class DensityLowerThanUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > DensityLowerThanUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `DensityLowerThanUP1D`
     '''
 
     def __init__(self, threshold: float, sigma: float = 2.0):
@@ -37,7 +37,7 @@ class DensityLowerThanUP1D:
 
         :param threshold: The value of the threshold density. Any Interface1D having a density lower than this threshold will match.
         :type threshold: float
-        :param sigma: The sigma value defining the density evaluation window size used in the freestyle.functions.DensityF0D functor.
+        :param sigma: The sigma value defining the density evaluation window size used in the `freestyle.functions.DensityF0D` functor.
         :type sigma: float
         '''
         pass
@@ -54,7 +54,7 @@ class DensityLowerThanUP1D:
 
 
 class EqualToChainingTimeStampUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > freestyle.types.EqualToChainingTimeStampUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `freestyle.types.EqualToChainingTimeStampUP1D`
     '''
 
     def __init__(self, ts: int):
@@ -77,7 +77,7 @@ class EqualToChainingTimeStampUP1D:
 
 
 class EqualToTimeStampUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > EqualToTimeStampUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `EqualToTimeStampUP1D`
     '''
 
     def __init__(self, ts: int):
@@ -100,7 +100,7 @@ class EqualToTimeStampUP1D:
 
 
 class ExternalContourUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > ExternalContourUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ExternalContourUP1D`
     '''
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
@@ -115,7 +115,7 @@ class ExternalContourUP1D:
 
 
 class FalseBP1D:
-    ''' Class hierarchy: freestyle.types.BinaryPredicate1D > FalseBP1D
+    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `FalseBP1D`
     '''
 
     def __call__(self, inter1: 'freestyle.types.Interface1D',
@@ -133,7 +133,7 @@ class FalseBP1D:
 
 
 class FalseUP0D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate0D > FalseUP0D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate0D` > `FalseUP0D`
     '''
 
     def __call__(self, it: 'freestyle.types.Interface0DIterator') -> bool:
@@ -148,7 +148,7 @@ class FalseUP0D:
 
 
 class FalseUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > FalseUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `FalseUP1D`
     '''
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
@@ -163,7 +163,7 @@ class FalseUP1D:
 
 
 class Length2DBP1D:
-    ''' Class hierarchy: freestyle.types.BinaryPredicate1D > Length2DBP1D
+    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `Length2DBP1D`
     '''
 
     def __call__(self, inter1: 'freestyle.types.Interface1D',
@@ -212,7 +212,7 @@ class QuantitativeInvisibilityRangeUP1D:
 
 
 class QuantitativeInvisibilityUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > QuantitativeInvisibilityUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `QuantitativeInvisibilityUP1D`
     '''
 
     def __init__(self, qi: int = 0):
@@ -224,7 +224,7 @@ class QuantitativeInvisibilityUP1D:
         pass
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
-        ''' Returns true if the Quantitative Invisibility evaluated at an Interface1D, using the freestyle.functions.QuantitativeInvisibilityF1D functor, equals a certain user-defined value.
+        ''' Returns true if the Quantitative Invisibility evaluated at an Interface1D, using the `freestyle.functions.QuantitativeInvisibilityF1D` functor, equals a certain user-defined value.
 
         :param inter: An Interface1D object.
         :type inter: 'freestyle.types.Interface1D'
@@ -235,7 +235,7 @@ class QuantitativeInvisibilityUP1D:
 
 
 class SameShapeIdBP1D:
-    ''' Class hierarchy: freestyle.types.BinaryPredicate1D > SameShapeIdBP1D
+    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `SameShapeIdBP1D`
     '''
 
     def __call__(self, inter1: 'freestyle.types.Interface1D',
@@ -253,7 +253,7 @@ class SameShapeIdBP1D:
 
 
 class ShapeUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > ShapeUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `ShapeUP1D`
     '''
 
     def __init__(self, first: int, second: int = 0):
@@ -267,7 +267,7 @@ class ShapeUP1D:
         pass
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
-        ''' Returns true if the shape to which the Interface1D belongs to has the same freestyle.types.Id as the one specified by the user.
+        ''' Returns true if the shape to which the Interface1D belongs to has the same `freestyle.types.Id` as the one specified by the user.
 
         :param inter: An Interface1D object.
         :type inter: 'freestyle.types.Interface1D'
@@ -278,7 +278,7 @@ class ShapeUP1D:
 
 
 class TrueBP1D:
-    ''' Class hierarchy: freestyle.types.BinaryPredicate1D > TrueBP1D
+    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `TrueBP1D`
     '''
 
     def __call__(self, inter1: 'freestyle.types.Interface1D',
@@ -296,7 +296,7 @@ class TrueBP1D:
 
 
 class TrueUP0D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate0D > TrueUP0D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate0D` > `TrueUP0D`
     '''
 
     def __call__(self, it: 'freestyle.types.Interface0DIterator') -> bool:
@@ -311,7 +311,7 @@ class TrueUP0D:
 
 
 class TrueUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > TrueUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `TrueUP1D`
     '''
 
     def __call__(self, inter: 'freestyle.types.Interface1D') -> bool:
@@ -326,7 +326,7 @@ class TrueUP1D:
 
 
 class ViewMapGradientNormBP1D:
-    ''' Class hierarchy: freestyle.types.BinaryPredicate1D > ViewMapGradientNormBP1D
+    ''' Class hierarchy: `freestyle.types.BinaryPredicate1D` > `ViewMapGradientNormBP1D`
     '''
 
     def __init__(self,
@@ -360,7 +360,7 @@ class ViewMapGradientNormBP1D:
 
 
 class WithinImageBoundaryUP1D:
-    ''' Class hierarchy: freestyle.types.UnaryPredicate1D > WithinImageBoundaryUP1D
+    ''' Class hierarchy: `freestyle.types.UnaryPredicate1D` > `WithinImageBoundaryUP1D`
     '''
 
     def __init__(self, xmin: float, ymin: float, xmax: float, ymax: float):
