@@ -169,12 +169,10 @@ def viewport_set(x: int, y: int, xsize: int, ysize: int):
     :type x: int
     :param y: lower left corner of the viewport_set rectangle, in pixels.
     :type y: int
+    :param xsize: width and height of the viewport_set.
     :type xsize: int
+    :param ysize: width and height of the viewport_set.
     :type ysize: int
-    :param width:  width and height of the viewport_set.
-    :type width: typing.Any
-    :param height:  width and height of the viewport_set.
-    :type height: typing.Any
     '''
 
     pass
