@@ -3,8 +3,8 @@ import typing
 from . import kdtree
 from . import geometry
 from . import noise
-from . import bvhtree
 from . import interpolate
+from . import bvhtree
 
 GenericType = typing.TypeVar("GenericType")
 
@@ -86,9 +86,11 @@ class Color:
         pass
 
     @staticmethod
-    def freeze():
+    def freeze() -> 'Color':
         ''' Make this object immutable. After this the object can be hashed, used in dictionaries & sets.
 
+        :rtype: 'Color'
+        :return: An instance of this object.
         '''
         pass
 
@@ -345,9 +347,11 @@ class Euler:
         pass
 
     @staticmethod
-    def freeze():
+    def freeze() -> 'Euler':
         ''' Make this object immutable. After this the object can be hashed, used in dictionaries & sets.
 
+        :rtype: 'Euler'
+        :return: An instance of this object.
         '''
         pass
 
@@ -506,16 +510,16 @@ class Matrix:
 
     @classmethod
     def LocRotScale(
-            cls, location: typing.Optional['Vector'],
-            rotation: typing.Union[typing.Sequence[float], 'Quaternion', typing
-                                   .Sequence[float], 'Euler'],
+            cls, location: typing.Optional['Vector'], rotation: typing.
+            Optional[typing.Union[typing.Sequence[float], 'Quaternion', typing.
+                                  Sequence[float], 'Euler']],
             scale: typing.Optional['Vector']) -> 'Matrix':
         ''' Create a matrix combining translation, rotation and scale, acting as the inverse of the decompose() method. Any of the inputs may be replaced with None if not needed.
 
         :param location: The translation component.
         :type location: typing.Optional['Vector']
         :param rotation: The rotation component.
-        :type rotation: typing.Union[typing.Sequence[float], 'Quaternion', typing.Sequence[float], 'Euler']
+        :type rotation: typing.Optional[typing.Union[typing.Sequence[float], 'Quaternion', typing.Sequence[float], 'Euler']]
         :param scale: The scale component.
         :type scale: typing.Optional['Vector']
         :rtype: 'Matrix'
@@ -638,9 +642,11 @@ class Matrix:
         pass
 
     @staticmethod
-    def freeze():
+    def freeze() -> 'Matrix':
         ''' Make this object immutable. After this the object can be hashed, used in dictionaries & sets.
 
+        :rtype: 'Matrix'
+        :return: An instance of this object.
         '''
         pass
 
@@ -805,9 +811,10 @@ class Matrix:
         '''
         pass
 
-    def zero(self):
+    def zero(self) -> 'Matrix':
         ''' Set all the matrix values to zero.
 
+        :rtype: 'Matrix'
         '''
         pass
 
@@ -821,6 +828,15 @@ class Matrix:
         '''
         pass
 
+    def __getitem__(self, key: int) -> 'Vector':
+        ''' 
+
+        :param key: 
+        :type key: int
+        :rtype: 'Vector'
+        '''
+        pass
+
     def __len__(self) -> int:
         ''' 
 
@@ -1043,16 +1059,19 @@ class Quaternion:
         pass
 
     @staticmethod
-    def freeze():
+    def freeze() -> 'Quaternion':
         ''' Make this object immutable. After this the object can be hashed, used in dictionaries & sets.
 
+        :rtype: 'Quaternion'
+        :return: An instance of this object.
         '''
         pass
 
     @staticmethod
-    def identity():
+    def identity() -> 'Quaternion':
         ''' Set the quaternion to an identity quaternion.
 
+        :rtype: 'Quaternion'
         '''
         pass
 
@@ -1079,9 +1098,10 @@ class Quaternion:
         pass
 
     @staticmethod
-    def negate():
+    def negate() -> 'Quaternion':
         ''' Set the quaternion to its negative.
 
+        :rtype: 'Quaternion'
         '''
         pass
 
@@ -1139,10 +1159,10 @@ class Quaternion:
         '''
         pass
 
-    def to_axis_angle(self) -> typing.Tuple['mathutils.Vector', float]:
+    def to_axis_angle(self) -> typing.Tuple['Vector', 'float']:
         ''' Return the axis, angle representation of the quaternion.
 
-        :rtype: typing.Tuple['mathutils.Vector', float]
+        :rtype: typing.Tuple['Vector', 'float']
         :return: axis, angle.
         '''
         pass
@@ -1177,13 +1197,13 @@ class Quaternion:
         '''
         pass
 
-    def to_swing_twist(self, axis: typing.Any
-                       ) -> typing.Tuple['mathutils.Quaternion', float]:
+    def to_swing_twist(
+            self, axis: typing.Any) -> typing.Tuple['Quaternion', 'float']:
         ''' Split the rotation into a swing quaternion with the specified axis fixed at zero, and the remaining twist rotation angle.
 
         :param axis:  twist axis as a string in ['X', 'Y', 'Z']
         :type axis: typing.Any
-        :rtype: typing.Tuple['mathutils.Quaternion', float]
+        :rtype: typing.Tuple['Quaternion', 'float']
         :return: swing, twist angle.
         '''
         pass
@@ -2513,9 +2533,11 @@ class Vector:
         pass
 
     @staticmethod
-    def freeze():
+    def freeze() -> 'Vector':
         ''' Make this object immutable. After this the object can be hashed, used in dictionaries & sets.
 
+        :rtype: 'Vector'
+        :return: An instance of this object.
         '''
         pass
 
